@@ -3,33 +3,49 @@ from pathlib import Path
 
 import pytest
 
-from pydata_factory.data import gen_data_from_schema, gen_data_from_schemas
-from pydata_factory.schema import load_schema
+from pydata_factory.data import GenData
+from pydata_factory.schema import Schema
 
 
 @pytest.mark.parametrize("schema_name", ["fb2021", "msft2021"])
-def test_gen_data_from_schema(schema_name):
+def test_gen_data_individually(schema_name):
     """Test the creation of a new model from a parquet file."""
     origin = Path(__file__).parent / "data" / "schemas" / f"{schema_name}.json"
-
-    schema = load_schema(origin)
-    df = gen_data_from_schema(schema)
-
+    schema = Schema.load_file(origin)
+    schemas = {schema["name"]: schema}
+    df = GenData.generate(schemas)[Schema.get_qualified_name(schema)]
     assert not df.empty
 
 
-def test_gen_data_from_schemas():
+def test_gen_data_yahoo_batch():
     """Test the creation of a new model from a parquet file."""
-    schemas = []
+    schemas = {}
 
     for schema_name in ["fb2021", "msft2021"]:
         schema_path = (
             Path(__file__).parent / "data" / "schemas" / f"{schema_name}.json"
         )
-        schema = load_schema(schema_path)
-        schemas.append(schema)
+        schema = Schema.load_file(schema_path)
+        schemas[schema["name"]] = schema
 
-    dfs = gen_data_from_schemas(schemas)
+    dfs = GenData.generate(schemas)
+
+    for k, df in dfs.items():
+        assert not df.empty
+
+
+def test_gen_data_tasks_batch():
+    """Test the creation of a new model from a parquet file."""
+    schemas = {}
+
+    for schema_name in ["clients", "projects"]:
+        schema_path = (
+            Path(__file__).parent / "data" / "schemas" / f"{schema_name}.json"
+        )
+        schema = Schema.load_file(schema_path)
+        schemas[schema["name"]] = schema
+
+    dfs = GenData.generate(schemas)
 
     for k, df in dfs.items():
         assert not df.empty
